# aimastering

Aimastering - the Ruby gem for the AI Mastering API

This is a AI Mastering API document. You can use the mastering feature of [AI Mastering](https://aimastering.com) through this API.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.1.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build aimastering.gemspec
```

Then either install the gem locally:

```shell
gem install ./aimastering-1.1.0.gem
```
(for development, run `gem install --dev ./aimastering-1.1.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'aimastering', '~> 1.1.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'aimastering', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'aimastering'

# Setup authorization
Aimastering.configure do |config|
  # Configure API key authorization: bearer
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Aimastering::AccessTokenApi.new

begin
  #Create an API access token.
  result = api_instance.create_access_token
  p result
rescue Aimastering::ApiError => e
  puts "Exception when calling AccessTokenApi->create_access_token: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://api.bakuage.com:443*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Aimastering::AccessTokenApi* | [**create_access_token**](docs/AccessTokenApi.md#create_access_token) | **POST** /access_tokens | Create an API access token.
*Aimastering::AmazonSubscriptionApi* | [**list_amazon_subscriptions**](docs/AmazonSubscriptionApi.md#list_amazon_subscriptions) | **GET** /amazon_subscriptions | Get all accessable amazon subscriptions.
*Aimastering::AudioApi* | [**create_audio**](docs/AudioApi.md#create_audio) | **POST** /audios | Create a new audio.
*Aimastering::AudioApi* | [**download_audio**](docs/AudioApi.md#download_audio) | **GET** /audios/{id}/download | Download an audio data by id.
*Aimastering::AudioApi* | [**download_audio_by_token**](docs/AudioApi.md#download_audio_by_token) | **GET** /audios/download_by_token | Download an audio data by audio_download_token.
*Aimastering::AudioApi* | [**get_audio**](docs/AudioApi.md#get_audio) | **GET** /audios/{id} | Get an audio by id.
*Aimastering::AudioApi* | [**get_audio_analysis**](docs/AudioApi.md#get_audio_analysis) | **GET** /audios/{id}/analysis | Get an audio analysis by id.
*Aimastering::AudioApi* | [**get_audio_download_token**](docs/AudioApi.md#get_audio_download_token) | **GET** /audios/{id}/download_token | Get an audio download token by id.
*Aimastering::AudioApi* | [**list_audios**](docs/AudioApi.md#list_audios) | **GET** /audios | Get all audios accessable.
*Aimastering::ConfigApi* | [**get_config**](docs/ConfigApi.md#get_config) | **GET** /config | Get config.
*Aimastering::ExternalSearchApi* | [**search_external**](docs/ExternalSearchApi.md#search_external) | **GET** /external_search | Search external music and get name, url, thumbnails, etc.
*Aimastering::LibraryAudioApi* | [**create_library_audio**](docs/LibraryAudioApi.md#create_library_audio) | **POST** /library_audios | Create a new library audio.
*Aimastering::LibraryAudioApi* | [**create_library_audio_like**](docs/LibraryAudioApi.md#create_library_audio_like) | **POST** /library_audios/{id}/like | Create a new library audio like.
*Aimastering::LibraryAudioApi* | [**delete_library_audio**](docs/LibraryAudioApi.md#delete_library_audio) | **DELETE** /library_audios/{id} | Delete library audio.
*Aimastering::LibraryAudioApi* | [**get_library_audio**](docs/LibraryAudioApi.md#get_library_audio) | **GET** /library_audios/{id} | Get a library audio by id.
*Aimastering::LibraryAudioApi* | [**get_library_audio_analysis**](docs/LibraryAudioApi.md#get_library_audio_analysis) | **GET** /library_audios/{id}/analysis | Get a library audio analysis by id.
*Aimastering::LibraryAudioApi* | [**list_library_audios**](docs/LibraryAudioApi.md#list_library_audios) | **GET** /library_audios | Get all library audios accessable.
*Aimastering::LibraryAudioApi* | [**update_library_audio**](docs/LibraryAudioApi.md#update_library_audio) | **PUT** /library_audios/{id} | Update library audio.
*Aimastering::MasteringApi* | [**cancel_mastering**](docs/MasteringApi.md#cancel_mastering) | **PUT** /masterings/{id}/cancel | Cancel a mastering by id.
*Aimastering::MasteringApi* | [**create_mastering**](docs/MasteringApi.md#create_mastering) | **POST** /masterings | Create a new mastering.
*Aimastering::MasteringApi* | [**delete_mastering**](docs/MasteringApi.md#delete_mastering) | **DELETE** /masterings/{id} | Delete mastering.
*Aimastering::MasteringApi* | [**free_unlock_mastering**](docs/MasteringApi.md#free_unlock_mastering) | **PUT** /masterings/{id}/free_unlock | Free unlock a mastering by id.
*Aimastering::MasteringApi* | [**get_mastering**](docs/MasteringApi.md#get_mastering) | **GET** /masterings/{id} | Get a mastering by id.
*Aimastering::MasteringApi* | [**get_mastering_unlock_product**](docs/MasteringApi.md#get_mastering_unlock_product) | **GET** /masterings/{id}/unlock_product | Review a mastering by id.
*Aimastering::MasteringApi* | [**list_masterings**](docs/MasteringApi.md#list_masterings) | **GET** /masterings | Get all accessable masterings.
*Aimastering::MasteringApi* | [**publish_mastering**](docs/MasteringApi.md#publish_mastering) | **POST** /masterings/{id}/publish | Publish a mastering by id.
*Aimastering::MasteringApi* | [**review_mastering**](docs/MasteringApi.md#review_mastering) | **PUT** /masterings/{id}/review | Review a mastering by id.
*Aimastering::MasteringApi* | [**update_mastering**](docs/MasteringApi.md#update_mastering) | **PUT** /masterings/{id} | Update a mastering.
*Aimastering::PaymentApi* | [**create_payment**](docs/PaymentApi.md#create_payment) | **POST** /payments | Create a new payment.
*Aimastering::PaymentApi* | [**execute_payment**](docs/PaymentApi.md#execute_payment) | **PUT** /payments/{id}/execute | Execute a payment by id.
*Aimastering::PaymentApi* | [**get_payment**](docs/PaymentApi.md#get_payment) | **GET** /payments/{id} | Get a payment by id.
*Aimastering::PaymentApi* | [**list_payments**](docs/PaymentApi.md#list_payments) | **GET** /payments | Get all accessable payments.
*Aimastering::PaymentCustomerApi* | [**get_default_payment_customer**](docs/PaymentCustomerApi.md#get_default_payment_customer) | **GET** /payment_customers/default | Get a default payment customer.
*Aimastering::PlanApi* | [**list_plans**](docs/PlanApi.md#list_plans) | **GET** /plans | Get all accessable plans.
*Aimastering::SpSubscriptionApi* | [**create_sp_subscription**](docs/SpSubscriptionApi.md#create_sp_subscription) | **POST** /sp_subscriptions | Create a new smartphone subscription.
*Aimastering::SpSubscriptionApi* | [**list_sp_subscriptions**](docs/SpSubscriptionApi.md#list_sp_subscriptions) | **GET** /sp_subscriptions | Get all accessable smartphone subscriptions.
*Aimastering::StatisticsApi* | [**get_group_buy_statistics**](docs/StatisticsApi.md#get_group_buy_statistics) | **GET** /statistics/group_buy | Get group buy statistics.
*Aimastering::StatisticsApi* | [**list_anonymized_masterings**](docs/StatisticsApi.md#list_anonymized_masterings) | **GET** /statistics/anonymized_masterings | Get anonymized masterings.
*Aimastering::StatisticsApi* | [**list_kpis**](docs/StatisticsApi.md#list_kpis) | **GET** /statistics/kpis | Get KPIs.
*Aimastering::SubscriptionApi* | [**cancel_subscription**](docs/SubscriptionApi.md#cancel_subscription) | **PUT** /subscriptions/{id}/cancel | Cancel a subscription by id.
*Aimastering::SubscriptionApi* | [**cancel_subscription_cancellation**](docs/SubscriptionApi.md#cancel_subscription_cancellation) | **PUT** /subscriptions/{id}/cancel_cancellation | Cancel the subscription cancellation  by id.
*Aimastering::SubscriptionApi* | [**create_subscription**](docs/SubscriptionApi.md#create_subscription) | **POST** /subscriptions | Create a new subscription.
*Aimastering::SubscriptionApi* | [**get_subscription**](docs/SubscriptionApi.md#get_subscription) | **GET** /subscriptions/{id} | Get a subscription by id.
*Aimastering::SubscriptionApi* | [**list_subscriptions**](docs/SubscriptionApi.md#list_subscriptions) | **GET** /subscriptions | Get all accessable subscriptions.
*Aimastering::UserApi* | [**get_self**](docs/UserApi.md#get_self) | **GET** /users/self | Get self user.
*Aimastering::UserApi* | [**notify_registration**](docs/UserApi.md#notify_registration) | **PUT** /users/self/notify_registration | Notify user is registered.
*Aimastering::UserApi* | [**send_invitation**](docs/UserApi.md#send_invitation) | **POST** /users/self/send_invitation | Send invitation.
*Aimastering::UserApi* | [**update_self**](docs/UserApi.md#update_self) | **PUT** /users/self | Update self user.
*Aimastering::VideoApi* | [**download_video**](docs/VideoApi.md#download_video) | **GET** /videos/{id}/download | Download an video data by id.
*Aimastering::VideoApi* | [**download_video_by_token**](docs/VideoApi.md#download_video_by_token) | **GET** /videos/download_by_token | Download an video data by video_download_token.
*Aimastering::VideoApi* | [**get_video**](docs/VideoApi.md#get_video) | **GET** /videos/{id} | Get an video by id.
*Aimastering::VideoApi* | [**get_video_download_token**](docs/VideoApi.md#get_video_download_token) | **GET** /videos/{id}/download_token | Get an video download token by id.
*Aimastering::VideoApi* | [**list_videos**](docs/VideoApi.md#list_videos) | **GET** /videos | Get all videos accessable.


## Documentation for Models

 - [Aimastering::AccessToken](docs/AccessToken.md)
 - [Aimastering::AmazonSubscription](docs/AmazonSubscription.md)
 - [Aimastering::AnonymizedMastering](docs/AnonymizedMastering.md)
 - [Aimastering::Audio](docs/Audio.md)
 - [Aimastering::AudioAnalysis](docs/AudioAnalysis.md)
 - [Aimastering::AudioDownloadToken](docs/AudioDownloadToken.md)
 - [Aimastering::Config](docs/Config.md)
 - [Aimastering::ConfigAuth0](docs/ConfigAuth0.md)
 - [Aimastering::ConfigPaypal](docs/ConfigPaypal.md)
 - [Aimastering::ConfigStripe](docs/ConfigStripe.md)
 - [Aimastering::ConfigVersion](docs/ConfigVersion.md)
 - [Aimastering::ExternalSearchResult](docs/ExternalSearchResult.md)
 - [Aimastering::ExternalSearchResultItunes](docs/ExternalSearchResultItunes.md)
 - [Aimastering::ExternalSearchResultYoutube](docs/ExternalSearchResultYoutube.md)
 - [Aimastering::GroupBuyStatistics](docs/GroupBuyStatistics.md)
 - [Aimastering::JWT](docs/JWT.md)
 - [Aimastering::Kpi](docs/Kpi.md)
 - [Aimastering::LibraryAudio](docs/LibraryAudio.md)
 - [Aimastering::LibraryAudioAnalysis](docs/LibraryAudioAnalysis.md)
 - [Aimastering::LibraryAudioLike](docs/LibraryAudioLike.md)
 - [Aimastering::Mastering](docs/Mastering.md)
 - [Aimastering::Payment](docs/Payment.md)
 - [Aimastering::PaymentCustomer](docs/PaymentCustomer.md)
 - [Aimastering::Plan](docs/Plan.md)
 - [Aimastering::SpSubscription](docs/SpSubscription.md)
 - [Aimastering::Subscription](docs/Subscription.md)
 - [Aimastering::User](docs/User.md)
 - [Aimastering::UserStatistics](docs/UserStatistics.md)
 - [Aimastering::Video](docs/Video.md)
 - [Aimastering::VideoDownloadToken](docs/VideoDownloadToken.md)


## Documentation for Authorization


### bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

